--
-- Shuttle Control
-- Shuttle implementation for steerables
-- Templaer
-- 22/11/2010
--

ShuttleControl = {};

-- Extended original functions --
function ShuttleControl:load(xmlFile)
	-- Add a reference to the new function --
	self.setShuttleDirection = ShuttleControl.setShuttleDirection;
	
	-- Shuttle enabled value, default is true --
	self.shuttleEnabled =  Utils.getNoNil(getXMLBool(xmlFile, "vehicle.shuttleDirection#enabled"), true);
	
	-- Actual shuttle direction --
	self.shuttleDirection = 1;
end;

function ShuttleControl:readStream(streamId, connection)
	local shuttleDirection = streamReadInt32(streamId);
	self:setShuttleDirection(shuttleDirection, true);	
end;

function ShuttleControl:writeStream(streamId, connection)
	streamWriteInt32(streamId, self.shuttleDirection);	
end;

function ShuttleControl:update(dt)
	if self:getIsActiveForInput() and self.shuttleEnabled then
		if InputBinding.hasEvent(InputBinding.SHUTTLE_CONTROL) then
			self:setShuttleDirection(-self.shuttleDirection);
		end;
	end;
end;

function ShuttleControl:draw()
	-- Check if the shuttle is enabled --
	if self.shuttleEnabled then
		-- Display the shuttle help text --
		if self.shuttleDirection == 1 then
			g_currentMission:addHelpButtonText(g_i18n:getText("Shuttle_control_forwards"), InputBinding.SHUTTLE_CONTROL);
		else
			g_currentMission:addHelpButtonText(g_i18n:getText("Shuttle_control_backwards"), InputBinding.SHUTTLE_CONTROL);
		end;
	end;
end;

-- New function --
function ShuttleControl:setShuttleDirection(shuttleDirection, noEventSend) 
	SetShuttleDirectionEvent.sendEvent(self, shuttleDirection, noEventSend);
	self.shuttleDirection = shuttleDirection;
end;

-- Append the functions to the original functions --
Steerable.load = Utils.appendedFunction(Steerable.load, ShuttleControl.load);
Steerable.readStream = Utils.appendedFunction(Steerable.readStream, ShuttleControl.readStream);
Steerable.writeStream = Utils.appendedFunction(Steerable.writeStream, ShuttleControl.writeStream);
Steerable.update = Utils.appendedFunction(Steerable.update, ShuttleControl.update);
Steerable.draw = Utils.appendedFunction(Steerable.draw, ShuttleControl.draw);